import json
import os
from ...services import project,config,printer
from terminal import gray,red

def debug(task_name, docker_image):

    project.check_is_job_project()


    with open('job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}

    task = obj['TaskDag']['TaskDescMap'].get(task_name)
    if not task:
        raise Exception('Not found task %s' % task_name)

    job_name = obj.get('JobName')
    local_path = os.path.join(os.getcwd(), 'src')


    oss_host = get_oss_host()

    m = {
        'USER': 'admin',
        'HOME':'/home/admin',
        'ALI_DIKU_INSTANCE_ID': 0,
        'ALI_DIKU_TASK_ID': task_name,
        'ALI_DIKU_JOB_ID':'job-0000000000',
        'ALI_DIKU_JOB_NAME': job_name,
        'ALI_DIKU_OSS_HOST': oss_host
    }

    env_vars = task.get('EnvironmentVariables')
    if env_vars:
        for k in env_vars:
            m[k] = env_vars[k]


    envs = ''.join([ (' -e %s=%s' % (k, m[k]) ) for k in m ])

    cmd = """docker run -it -v %s:/home/admin %s %s %s /home/admin/%s %s""" % (
        local_path, envs, docker_image, task.get('ProgramType'), task.get('ProgramName'), task.get('ProgramArguments') or '')


    print(gray(cmd))

    with os.popen(cmd) as f:
        result = f.read()
        if result:
            print(red(result))
        else:
            printer.done()



def get_oss_host():
    opt = config.getConfigs(config.COMMON, ['region','endpoint'])
    if opt.get('region'):
        oss_host = 'oss-%s.aliyuncs.com' % opt['region']
    elif opt.get('endpoint'):
        oss_host = 'oss-%s.aliyuncs.com' % parse_region_id(opt.get('endpoint'))
    else:
        raise Exception('You need to login first')


def parse_region_id(endpoint):
    return endpoint[len('batchcompute.'): -len('.aliyuncs.com')]